@@ -2,6 +2,7 @@ from pandas import DataFrame,json_normalize,concat,ExcelWriter
 from os import mkdir
 from os.path import exists,abspath,join
 from subprocess import Popen,PIPE,STDOUT
+from pandas.api.types import is_numeric_dtype
 import sys
 
 
@@ -177,40 +178,48 @@ def check_process(process:Popen,output=True):
     return process.returncode,ret
     
 
-def format_table(writer, data, sheet_name,width=None):
+def format_table(writer, data, sheet_name,width=None,total_line=False):
     
-    data.to_excel(writer, index=False, sheet_name=sheet_name, startrow=1,header=False,float_format = "%0.2f")
+    data.to_excel(writer, index=False, sheet_name=sheet_name, startrow=1,header=False)
 
     workbook = writer.book
     worksheet = writer.sheets[sheet_name]
     rows = len(data)
     cols = len(data.columns)-1
+
     columns=[]
+    first=True
     for col_num, value in enumerate(data.columns.values):
-        columns.append({'header': value})
+        json = {'header': value}
+        if first:
+            first=False
+            if total_line:
+                json['total_string']='Totals'
+        else: 
+            if is_numeric_dtype(data[value]) and data[value].dtype != 'bool':
+                if total_line:
+                    json['total_function']='sum'
+
+        columns.append(json)
 
     table_options={
+                'total_row':total_line,
                 'columns':columns,
                 'header_row':True,
                 'autofilter':True,
                 'banded_rows':True
                 }
     worksheet.add_table(0, 0, rows, cols,table_options)
-    
-    header_format = workbook.add_format({'text_wrap':True,
-                                        'align': 'center'})
 
     col_width = 10
     if width == None:
         width = []
         for i in range(1,len(data.columns)+1):
            width.append(col_width)
-    for col_num, value in enumerate(data.columns.values):
-        worksheet.write(0, col_num, value, header_format)
-        w=width[col_num]
-        worksheet.set_column(col_num, col_num, w)
+
     return worksheet
 
+
 def convert_LOC(total:int):
     unit = ''
     if 1000 <= total <= 1000000:
